pub struct Config {Show 13 fields
pub use_fake_bti: bool,
pub use_fake_smc: bool,
pub use_fake_irq: bool,
pub mmios: HashMap<u32, Mmio>,
pub mmio_names: HashMap<String, u32>,
pub irqs: HashMap<u32, Interrupt>,
pub irq_names: HashMap<String, u32>,
pub btis: HashMap<u32, Bti>,
pub bti_names: HashMap<String, u32>,
pub smcs: HashMap<u32, Resource>,
pub device_info: Option<NodeDeviceInfo>,
pub board_info: Option<BoardInfo>,
pub power_elements: Vec<PowerElementConfiguration>,
}Expand description
Holds resources used to create a FakePDev instance.
Fields
use_fake_bti: boolIf true, a BTI will be generated lazily if it does not exist.
use_fake_smc: boolIf true, an SMC will be generated lazily if it does not exist.
use_fake_irq: boolIf true, an interrupt will be generated lazily if it does not exist.
mmios: HashMap<u32, Mmio>Key is the index of the MMIO.
mmio_names: HashMap<String, u32>Maps the name of an MMIO to the index of the MMIO. The key is the name of the MMIO and the value is the index of the MMIO.
irqs: HashMap<u32, Interrupt>Key is the index of the interrupt.
irq_names: HashMap<String, u32>Maps the name of an interrupt to the index of the interrupt. The key is the name of the interrupt and the value is the index of the interrupt.
btis: HashMap<u32, Bti>Key is the index of the BTI.
bti_names: HashMap<String, u32>Maps the name of an BTI to the index of the BTI. The key is the name of the BTI and the value is the index of the BTI.
smcs: HashMap<u32, Resource>Key is the index of the SMC.
device_info: Option<NodeDeviceInfo>The info to pass provide to GetNodeDeviceInfo().
board_info: Option<BoardInfo>The info to pass provide to GetBoardInfo().
power_elements: Vec<PowerElementConfiguration>The power elements to provide to GetPowerConfiguration().